==> zio-aws-appmesh_2.12-5.17.104.11-sources.jar: zio/aws/appmesh/model/GrpcRouteMetadataMatchMethod.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.HeaderMatch
import scala.jdk.CollectionConverters._
final case class GrpcRouteMetadataMatchMethod(
    exact: Option[HeaderMatch] = None,
    prefix: Option[HeaderMatch] = None,
    range: Option[zio.aws.appmesh.model.MatchRange] = None,
    regex: Option[HeaderMatch] = None,
    suffix: Option[HeaderMatch] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod = {
    import GrpcRouteMetadataMatchMethod.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
      .builder()
      .optionallyWith(
        exact.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.exact)
      .optionallyWith(
        prefix.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(range.map(value => value.buildAwsValue()))(_.range)
      .optionallyWith(
        regex.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.regex)
      .optionallyWith(
        suffix.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.suffix)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly =
    zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.wrap(buildAwsValue())
}
object GrpcRouteMetadataMatchMethod {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod =
      zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod(
        exact.map(value => value),
        prefix.map(value => value),
        range.map(value => value.asEditable),
        regex.map(value => value),
        suffix.map(value => value)
      )
    def exact: Option[HeaderMatch]
    def prefix: Option[HeaderMatch]
    def range: Option[zio.aws.appmesh.model.MatchRange.ReadOnly]
    def regex: Option[HeaderMatch]
    def suffix: Option[HeaderMatch]
    def getExact: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("exact", exact)
    def getPrefix: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getRange
        : ZIO[Any, AwsError, zio.aws.appmesh.model.MatchRange.ReadOnly] =
      AwsError.unwrapOptionField("range", range)
    def getRegex: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("regex", regex)
    def getSuffix: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("suffix", suffix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ) extends zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly {
    override val exact: Option[HeaderMatch] = scala
      .Option(impl.exact())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val prefix: Option[HeaderMatch] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val range: Option[zio.aws.appmesh.model.MatchRange.ReadOnly] =
      scala
        .Option(impl.range())
        .map(value => zio.aws.appmesh.model.MatchRange.wrap(value))
    override val regex: Option[HeaderMatch] = scala
      .Option(impl.regex())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val suffix: Option[HeaderMatch] = scala
      .Option(impl.suffix())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ): zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appmesh_2.12-6.20.58.3-sources.jar: zio/aws/appmesh/model/GrpcRouteMetadataMatchMethod.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.HeaderMatch
import scala.jdk.CollectionConverters._
final case class GrpcRouteMetadataMatchMethod(
    exact: Optional[HeaderMatch] = Optional.Absent,
    prefix: Optional[HeaderMatch] = Optional.Absent,
    range: Optional[zio.aws.appmesh.model.MatchRange] = Optional.Absent,
    regex: Optional[HeaderMatch] = Optional.Absent,
    suffix: Optional[HeaderMatch] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod = {
    import GrpcRouteMetadataMatchMethod.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
      .builder()
      .optionallyWith(
        exact.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.exact)
      .optionallyWith(
        prefix.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(range.map(value => value.buildAwsValue()))(_.range)
      .optionallyWith(
        regex.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.regex)
      .optionallyWith(
        suffix.map(value => HeaderMatch.unwrap(value): java.lang.String)
      )(_.suffix)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly =
    zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.wrap(buildAwsValue())
}
object GrpcRouteMetadataMatchMethod {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod =
      zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod(
        exact.map(value => value),
        prefix.map(value => value),
        range.map(value => value.asEditable),
        regex.map(value => value),
        suffix.map(value => value)
      )
    def exact: Optional[HeaderMatch]
    def prefix: Optional[HeaderMatch]
    def range: Optional[zio.aws.appmesh.model.MatchRange.ReadOnly]
    def regex: Optional[HeaderMatch]
    def suffix: Optional[HeaderMatch]
    def getExact: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("exact", exact)
    def getPrefix: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getRange
        : ZIO[Any, AwsError, zio.aws.appmesh.model.MatchRange.ReadOnly] =
      AwsError.unwrapOptionField("range", range)
    def getRegex: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("regex", regex)
    def getSuffix: ZIO[Any, AwsError, HeaderMatch] =
      AwsError.unwrapOptionField("suffix", suffix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ) extends zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly {
    override val exact: Optional[HeaderMatch] = zio.aws.core.internal
      .optionalFromNullable(impl.exact())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val prefix: Optional[HeaderMatch] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val range: Optional[zio.aws.appmesh.model.MatchRange.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.range())
        .map(value => zio.aws.appmesh.model.MatchRange.wrap(value))
    override val regex: Optional[HeaderMatch] = zio.aws.core.internal
      .optionalFromNullable(impl.regex())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
    override val suffix: Optional[HeaderMatch] = zio.aws.core.internal
      .optionalFromNullable(impl.suffix())
      .map(value => zio.aws.appmesh.model.primitives.HeaderMatch(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.GrpcRouteMetadataMatchMethod
  ): zio.aws.appmesh.model.GrpcRouteMetadataMatchMethod.ReadOnly = new Wrapper(
    impl
  )
}
